FlutterSliderTooltip class

Constructors

FlutterSliderTooltip({Widget custom(dynamic value)?, String format(String value)?, TextStyle? textStyle, FlutterSliderTooltipBox? boxStyle, Widget? leftPrefix, Widget? leftSuffix, Widget? rightPrefix, Widget? rightSuffix, bool? alwaysShowTooltip, bool? disableAnimation, bool? disabled, FlutterSliderTooltipDirection? direction, FlutterSliderTooltipPositionOffset? positionOffset})

Properties

alwaysShowTooltip ↔ bool?
getter/setter pair
boxStyle ↔ FlutterSliderTooltipBox?
getter/setter pair
custom ↔ Widget Function(dynamic value)?
getter/setter pair
direction ↔ FlutterSliderTooltipDirection?
getter/setter pair
disableAnimation ↔ bool?
getter/setter pair
disabled ↔ bool?
getter/setter pair
format ↔ String Function(String value)?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leftPrefix ↔ Widget?
getter/setter pair
leftSuffix ↔ Widget?
getter/setter pair
positionOffset ↔ FlutterSliderTooltipPositionOffset?
getter/setter pair
rightPrefix ↔ Widget?
getter/setter pair
rightSuffix ↔ Widget?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited